CREATE TABLE Mitarbeiter (
  svnr        NUMERIC(10) PRIMARY KEY,
  vname       VARCHAR(50) NOT NULL,
  nname       VARCHAR(50) NOT NULL);

CREATE TABLE Veranstaltungsort (
  VONR	  INTEGER PRIMARY KEY,
  bez     VARCHAR(50) NOT NULL,
  leiter  NUMERIC(10) NOT NULL REFERENCES Mitarbeiter (svnr) UNIQUE);

CREATE TABLE arbeitet (
  mitarbeiter       NUMERIC(10) NOT NULL REFERENCES Mitarbeiter(svnr),
  veranstaltungsort INTEGER NOT NULL REFERENCES Veranstaltungsort (VONR),
  funktion          VARCHAR(50) NOT NULL,
  gehalt	    NUMERIC(10,2) NOT NULL,
  PRIMARY KEY (mitarbeiter, veranstaltungsort));

CREATE TABLE Saal (
  snr               INTEGER PRIMARY KEY,
  veranstaltungsort INTEGER NOT NULL REFERENCES Veranstaltungsort (VONR),
  bez               VARCHAR(50) NOT NULL);
  
CREATE TABLE Kategorie (
  kid   INTEGER PRIMARY KEY,
  bez   VARCHAR(50) NOT NULL,
  preis NUMERIC(10,2) NOT NULL);
  
CREATE TABLE Reihe (
  rnr         INTEGER NOT NULL,
  snr         INTEGER NOT NULL REFERENCES Saal,
  kategorie   INTEGER NOT NULL REFERENCES Kategorie (kid),
  PRIMARY KEY (rnr, snr));
  
CREATE TABLE Platz (
  pnr   INTEGER NOT NULL,
  rnr   INTEGER NOT NULL,
  snr 	INTEGER NOT NULL,
  FOREIGN KEY (rnr, snr) REFERENCES Reihe (rnr, snr),
  PRIMARY KEY (pnr, rnr, snr));

CREATE TABLE Veranstaltung (
  vid           INTEGER PRIMARY KEY,
  bez           VARCHAR(50) NOT NULL,
  beschreibung  VARCHAR(50) NOT NULL,
  dauer         INTEGER NOT NULL);
  
CREATE TABLE findet_statt (
  veranstaltung INTEGER NOT NULL REFERENCES Veranstaltung (vid),
  saal          INTEGER NOT NULL REFERENCES Saal (snr),
  von           TIMESTAMP NOT NULL,
  bis           TIMESTAMP NOT NULL,
  PRIMARY KEY (veranstaltung, saal, von));
  
CREATE TABLE Merchandiseartikel (
  hersteller    VARCHAR(50) NOT NULL,
  bez           VARCHAR(20) NOT NULL,
  preis         NUMERIC(10,2) NOT NULL,
  wirbt_fuer    INTEGER NOT NULL REFERENCES Veranstaltung (vid),
  PRIMARY KEY (hersteller, bez));
  
CREATE TABLE bietet_an (
  veranstaltungsort INTEGER NOT NULL REFERENCES Veranstaltungsort (VONR),
  hersteller        VARCHAR(50) NOT NULL,
  bez               VARCHAR(20) NOT NULL,
  lagerstand        INTEGER NOT NULL,
  FOREIGN KEY (hersteller, bez) REFERENCES Merchandiseartikel,
  PRIMARY KEY (veranstaltungsort, hersteller, bez));
  
CREATE TABLE Film (
  vid           INTEGER PRIMARY KEY REFERENCES Veranstaltung (vid),
  regisseur     VARCHAR(50) NOT NULL,
  genre         VARCHAR(50) NOT NULL,
  fsk           INTEGER NOT NULL CHECK (fsk IN (0,6,12,16,18)));
  
CREATE TABLE Kunde (
  knr   INTEGER PRIMARY KEY,
  nname VARCHAR(50) NOT NULL);
  
CREATE TABLE Premiumkunde (
  knr         INTEGER PRIMARY KEY REFERENCES Kunde (knr),
  vname       VARCHAR(50) NOT NULL,
  gebdat      DATE NOT NULL,
  telefon     VARCHAR(50) NOT NULL,
  geschlecht  VARCHAR(9) NOT NULL CHECK (geschlecht IN ('maennlich','weiblich')),
  adresse     VARCHAR(100) NOT NULL,
  email       VARCHAR(40) NOT NULL,
  passwort    VARCHAR(50) NOT NULL);
  
CREATE TABLE Ticket (
  tnr           INTEGER PRIMARY KEY,
  veranstaltung INTEGER NOT NULL REFERENCES Veranstaltung (vid),
  platz         INTEGER NOT NULL,
  reihe         INTEGER NOT NULL,
  saal          INTEGER NOT NULL,
  FOREIGN KEY (platz, reihe, saal) REFERENCES Platz (pnr, rnr, snr));
  
CREATE TABLE reserviert (
  ticket    INTEGER PRIMARY KEY REFERENCES Ticket (tnr),
  kunde     INTEGER NOT NULL REFERENCES Kunde (knr),
  zeitpunkt TIMESTAMP NOT NULL);
  
CREATE TABLE kauft (
  kunde         INTEGER NOT NULL REFERENCES Premiumkunde (knr),
  hersteller    VARCHAR(50) NOT NULL,
  bez           VARCHAR(50) NOT NULL,
  stueck        INTEGER NOT NULL,
  PRIMARY KEY (kunde, hersteller, bez),
  FOREIGN KEY (hersteller, bez) REFERENCES Merchandiseartikel);